#!/usr/bin/python3

import sys
import random

default = {
    "n": 10,
    "part": 5,
    "mode": "bipartite",
    "complement": 0,
    "m": 0,
}

def cmdlinearg(name):
    for arg in sys.argv:
        if arg.startswith(name + "="):
            return arg.split("=")[1]
    return default[name]

def main():

    random.seed(int(sys.argv[-1]))
    n = int(cmdlinearg("n"))
    part = int(cmdlinearg("part"))
    mode = cmdlinearg("mode")
    complement = int(cmdlinearg("complement"))
    m = int(cmdlinearg("m"))
    
    edges = []

    if mode == "bipartite":
        for i in range(0, part):
            for j in range(i+1, part):
                edges.append((i, j))
        for i in range(part, n):
            for j in range(i+1, n):
                edges.append((i, j))
    elif mode == "leftstar":
        for i in range(1, part):
            edges.append((0, i))
        for i in range(part, n):
            for j in range(i+1, n):
                edges.append((i, j))
    elif mode == "rightstar":
        for i in range(0, part):
            for j in range(i+1, part):
                edges.append((i, j))
        for i in range(part+1, n):
            edges.append((part, i))
    elif mode == "antigreedy":
        # 1 is connected to everything, the rest is two disconnected cliques
        for i in range(1, n):
            edges.append((0, i))
        for i in range(1, part+1):
            for j in range(i+1, part+1):
                edges.append((i, j))
        for i in range(part+1, n):
            for j in range(i+1, n):
                edges.append((i, j))
    elif mode == "isolate":
        # 1 is connected to nobody, the rest is a bipartite graph
        edge_set = set()
        if part*(n-part-1) > 1000000:
            while len(edges) < m:
                u = random.randint(1, part)
                v = random.randrange(part+1,n)
                if (u, v) not in edge_set:
                    edge_set.add((u, v))
                    edge_set.add((v, u))
                    edges.append((u, v))
        else:
            all_edges = []
            for u in range(1, part+1):
                for v in range(part+1, n):
                    all_edges.append((u, v))
            random.shuffle(all_edges)
            for i in range(min(len(all_edges), m)):
                edges.append(all_edges[i])
    
    remap = list(range(1, n))
    random.shuffle(remap)
    remap = [0] + remap

    if complement == 1:
        edges2 = []
        edge_set = set()
        for (u, v) in edges:
            edge_set.add((u, v))
            edge_set.add((v, u))
        for i in range(0, n):
            for j in range(i+1, n):
                if (i, j) not in edge_set:
                    edges2.append((i, j))
        edges = edges2 


    print(n, len(edges))
    for (u, v) in edges:
        print(remap[u]+1, remap[v]+1)
    
    
if __name__ == "__main__":
    main()
